@@ -109,7 +109,8 @@ class Point:
     def action(self):
         if self._action is None:
             raise PointError('Action not set.')
-        self._client.get()
+        if self._client.get().status_code != status.HTTP_200_OK:
+            raise PointClientError('not_200_ok')
 
     @property
     def _query_params(self) -> dict:
